# remirepo spec file for php-pecl-ip2proxy
#
# SPDX-FileCopyrightText:  Copyright 2020-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#

%{?scl:%scl_package      php-pecl-ip2proxy}

%bcond_without           tests

%global pecl_name        ip2proxy
%global with_zts         0%{!?_without_zts:%{?__ztsphp:1}}
%global ini_name         40-%{pecl_name}.ini
%global upstream_version 3.0.3
#global upstream_prever  RC1
%global sources          %{pecl_name}-%{upstream_version}%{?upstream_prever}
%global _configure       ../%{sources}/configure

# see https://github.com/ip2location/ip2proxy-c/commits/master
%global gh_owner    ip2location
%global gh_project  ip2proxy-c
%global gh_commit   75beea905bd25fdba9d8fb965f958ba3c9c552f7
%global gh_version  4.2.0
%global gh_short    %(c=%{gh_commit}; echo ${c:0:7})

Summary:        Get proxy information of an IP address
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
# library is MIT, extension is PHP
License:        MIT and PHP-3.01
Version:        %{upstream_version}%{?upstream_prever:~%{upstream_prever}}
Release:        5%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}
URL:            https://pecl.php.net/package/igbinary
Source0:        https://pecl.php.net/get/%{sources}.tgz

# library with no API nor ABI management
Source1:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{gh_project}-%{gh_version}-%{gh_short}.tar.gz
Patch0:         %{pecl_name}-bundledlib.patch
Provides:       bundled(%{gh_project}) = %{gh_version}

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  %{?scl_prefix}php-devel

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}                = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}        = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})          = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa}  = %{version}


%description
This PECL extension allows you to detect proxy servers with country,
region, city, ISP, domain, usage type, ASN, security threat and proxy
type information using IP2Proxy binary database.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c -a 1
mv %{gh_project}-%{gh_commit}/libIP2Proxy libIP2Proxy
mv %{gh_project}-%{gh_commit}/LICENSE.TXT LICENSE-%{gh_project}
sed -e 's:../config.h:config.h:' -i libIP2Proxy/IP2Proxy.c

# Don't install tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -e '/README.TXT/s/role="doc"/role="src"/' \
    -i package.xml


cd %{sources}
%patch -P0 -p1 -b .rpm

# Check version
extver=$(sed -n '/#define PHP_IP2PROXY_VERSION/{s/.* "//;s/".*$//;p}' php_ip2proxy.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}"; then
   : Error: Upstream version is ${extver}, expecting %{upstream_version}%{?upstream_prever}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

cat <<EOF | tee %{ini_name}
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}
[ -f Makefile.global ] && GLOBAL=Makefile.global || GLOBAL=build/Makefile.global
sed -e 's/INSTALL_ROOT/DESTDIR/' -i $GLOBAL

cd ../NTS
%configure \
  --with-ip2proxy=../libIP2Proxy \
  --with-php-config=%{__phpconfig}

%make_build

%if %{with_zts}
cd ../ZTS
%configure \
  --with-ip2proxy=../libIP2Proxy \
  --with-php-config=%{__ztsphpconfig}

%make_build
%endif


%install
%{?dtsenable}

%make_install -C NTS

install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install the ZTS stuff
%if %{with_zts}
%make_install -C ZTS
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd %{sources}

: simple NTS module load test
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with tests}
: upstream test suite
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -q --show-diff
%endif

%if %{with_zts}
: simple ZTS module load test
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with tests}
: upstream test suite
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php -q --show-diff
%endif
%endif


%files
%license LICENSE-%{gh_project}
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%config(noreplace) %{php_inidir}/%{ini_name}

%{php_extdir}/%{pecl_name}.so
%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Tue Feb  4 2025 Remi Collet <remi@remirepo.net> - 3.0.3-5
- re-license spec file to CECILL-2.1
- update bundled libip2proxy to 4.2.1

* Tue Oct  1 2024 Remi Collet <remi@remirepo.net> - 3.0.3-4
- cleanup spec

* Fri Sep  1 2023 Remi Collet <remi@remirepo.net> - 3.0.3-3
- update bundled libip2proxy to 4.1.2

* Fri Sep  1 2023 Remi Collet <remi@remirepo.net> - 3.0.3-2
- build out of sources tree

* Tue Aug  2 2022 Remi Collet <remi@remirepo.net> - 3.0.3-1
- update to 3.0.3

* Fri Jul 29 2022 Remi Collet <remi@remirepo.net> - 3.0.2-1
- update to 3.0.2
- update bundled libip2proxy to 4.1.1
- open https://github.com/ip2location/ip2proxy-pecl/issues/4 broken sources

* Tue Nov 23 2021 Remi Collet <remi@remirepo.net> - 3.0.1-2
- update bundled libip2proxy to 4.0.1

* Fri Oct 23 2020 Remi Collet <remi@remirepo.net> - 3.0.1-1
- update to 3.0.1

* Thu Oct 22 2020 Remi Collet <remi@remirepo.net> - 3.0.0-2
- add bundled library license file

* Thu Oct 22 2020 Remi Collet <remi@remirepo.net> - 3.0.0-1
- initital RPM
- open https://github.com/ip2location/ip2proxy-pecl/issues/1 package.xml
- open https://github.com/ip2location/ip2proxy-pecl/issues/2 test suite
- open https://github.com/ip2location/ip2proxy-pecl/issues/3 empty file
